@@ -353,10 +353,11 @@ def discover_feed(url):
     try:
         icon_url = None
         content_type = None
+        content = page.read()
         if page.info().has_key("Content-Type"):
             content_type = page.info()["Content-Type"]
         if content_type and content_type.find("html") >=0:
-            html = parse_html(page, get_page_encoding(page))
+            html = parse_html(content, get_page_encoding(page))
             base = get_page_base(page, html)
             icon_tag = html.find(name = "link", attrs = {"rel": re.compile("icon", flags = re.I)})
             if icon_tag:
@@ -366,7 +367,7 @@ def discover_feed(url):
                 rss_tag = html.find(name = "link", attrs = {"rel": "alternate", "type": "application/atom+xml"})
             if rss_tag:
                 return get_feed_details(urljoin(base, rss_tag["href"]), icon_url)
-        return get_feed_details(url, icon_url, page)
+        return get_feed_details(url, icon_url, content)
     finally:
         page.close()
 
